# ![dynMix](dynmix.png)

This is a Python package focused on clustering and mixture models and is being developed as part of my master's dissertation. The objective is to include various routines for dealing with clustering time-series data, including a dynamic clustering option, which is being proposed in my dissertation.

It is currently undergoing development with a lot of changes and may contain errors. However, at your own risk, you may install and use the software through PyPi:
```pip install dynmix```

The project is subject to the terms of the Mozilla Public License, v. 2.0. See the LICENSE file in the root of the repository for further details.

###### Copyright &copy; Victhor S. Sartório. All rights reserved.
